/* For use by autoheader */

#ifndef CONFIG_H
#define CONFIG_H    /* To stop multiple inclusions. */

/* The NOFFLE config-file */
#undef CONFIGFILE

/* The NOFFLE users-file */
#undef USERSFILE

/* The default NOFFLE spool-directory */
#undef SPOOLDIR

/* Enable GNU extensions. */
#undef _GNU_SOURCE

/* Define to 'unsigned int' if not already defined by the system. */
#undef socklen_t

/* path to sendmail binary */
#undef SENDMAILPROG

/* Is authentication enabled? */
#undef USE_AUTH

/* Are we using PAM for authentication? */
#undef USE_PAM

@TOP@
/* autoheader generated things inserted here. */
@BOTTOM@


#endif /* CONFIG_H */

